summaryrefslogtreecommitdiffstats
path: root/kalarm/soundpicker.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/soundpicker.h')
-rw-r--r--kalarm/soundpicker.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kalarm/soundpicker.h b/kalarm/soundpicker.h
index eaf0ec16..5f89d535 100644
--- a/kalarm/soundpicker.h
+++ b/kalarm/soundpicker.h
@@ -43,10 +43,10 @@ class SoundPicker : public TQFrame
*/
enum Type { NONE = 0, BEEP, PLAY_FILE, SPEAK };
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit SoundPicker(TQWidget* tqparent, const char* name = 0);
+ explicit SoundPicker(TQWidget* parent, const char* name = 0);
/** Initialises the widget's state.
* @param type The option to select.
* @param filename The full path or URL of the sound file to select. If the 'file' option is
@@ -43,10 +43,10 @@ class SoundPicker : public TQFrame
enum Type { NONE = 0, BEEP, PLAY_FILE, SPEAK };
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/